@@ -1,4 +1,4 @@
-import contextlib, datetime, itertools, os, pathlib, random, re, subprocess, sys, time, uuid
+import argparse, contextlib, datetime, itertools, os, pathlib, random, re, subprocess, sys, time, uuid
 if sys.platform != "cygwin":
   import psutil
 
@@ -47,7 +47,7 @@ def jobinfo():
   return sys.platform, cpuid(), os.getpid()
 
 class JobLock(object):
-  defaultcorruptfiletimeout = None
+  defaultcorruptfiletimeout = datetime.timedelta(hours=24)
 
   def __init__(self, filename, *, outputfiles=[], checkoutputfiles=True, inputfiles=[], checkinputfiles=True, prevsteplockfiles=[], corruptfiletimeout=None, mkdir=False, dosqueue=True, cachesqueue=False):
     self.filename = pathlib.Path(filename)
@@ -77,7 +77,7 @@ class JobLock(object):
   def __reset(self):
     self.fd = self.f = None
     self.bool = False
-    self.__inputsexist = self.__outputsexist = self.__prevsteplockfilesexist = self.__oldjobinfo = None
+    self.__inputsexist = self.__outputsexist = self.__prevsteplockfilesexist = self.__oldjobinfo = self.__iterative_lock = None
 
   @property
   def wouldbevalid(self):
@@ -120,6 +120,14 @@ class JobLock(object):
   def oldjobinfo(self):
     return self.__oldjobinfo
 
+  @property
+  def iterative_lock(self):
+    return self.__iterative_lock
+  @property
+  def iterative_lock_debuginfo(self):
+    if self.iterative_lock is None: return None
+    return self.iterative_lock.debuginfo
+
   def __open(self):
     self.fd = os.open(self.filename, os.O_CREAT | os.O_EXCL | os.O_WRONLY)
 
@@ -163,7 +171,7 @@ class JobLock(object):
             break
 
   def __enter__(self):
-    self.removed_failed_job = removed_failed_job = False
+    self.removed_failed_job = False
     if self.checkoutputfiles and not self.filename.exists():
       self.__outputsexist = {_: _.exists() for _ in self.outputfiles}
       if all(self.outputsexist.values()):
@@ -188,6 +196,7 @@ class JobLock(object):
       #job failed at the same time, and one of them could remove
       #the lock created by the other one
       with JobLock(self.iterative_lock_filename, **self.sublockkwargs) as iterative_lock:
+        self.__iterative_lock = iterative_lock
         if not iterative_lock: return self
         try:
           self.__oldjobinfo = self.runningjobinfo(exceptions=True)
@@ -206,7 +215,7 @@ class JobLock(object):
               for outputfile in self.outputfiles:
                 rm_missing_ok(outputfile)
               rm_missing_ok(self.filename)
-              removed_failed_job = True
+              self.removed_failed_job = True
               try:
                 self.__open()
               except FileExistsError:
@@ -220,7 +229,7 @@ class JobLock(object):
             for outputfile in self.outputfiles:
               rm_missing_ok(outputfile)
             rm_missing_ok(self.filename)
-            self.removed_failed_job = removed_failed_job = True
+            self.removed_failed_job = True
             try:
               self.__open()
             except FileExistsError:
@@ -240,7 +249,6 @@ class JobLock(object):
     except (IOError, OSError):
       pass
     self.bool = True
-    self.removed_failed_job = removed_failed_job
     return self
 
   def __exit__(self, exc_type, exc, traceback):
@@ -266,6 +274,7 @@ class JobLock(object):
       "prevsteplockfilesexist": self.prevsteplockfilesexist,
       "oldjobinfo": self.oldjobinfo,
       "removed_failed_job": self.removed_failed_job,
+      "iterative_lock_debuginfo": self.iterative_lock_debuginfo,
     }
 
 __knownrunningslurmjobs = set()
@@ -422,6 +431,16 @@ def clean_up_old_job_locks(folder, glob="*.lock_*", howold=datetime.timedelta(da
   doprint(f"{dontverb} the following locks (and their iterations):")
   for _ in dontremove: doprint(_)
 
+def clean_up_old_job_locks_argparse(args=None):
+  p = argparse.ArgumentParser()
+  p.add_argument("folder", type=pathlib.Path)
+  p.add_argument("--glob", default="*.lock_*")
+  p.add_argument("--hours-old", type=lambda x: datetime.timedelta(hours=float(x)), default=7*24, dest="howold")
+  p.add_argument("--dry-run", dest="dryrun", action="store_true")
+  p.add_argument("--silent", action="store_true")
+  args = p.parse_args(args=args)
+  return clean_up_old_job_locks(**args.__dict__)
+
 class MultiJobLock(contextlib.ExitStack):
   """
   JobLock with multiple files.
