@@ -370,6 +370,7 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     with open(self.tmpdir/"lock1.lock", "w"): pass
     with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=1)) as lock:
       self.assertFalse(lock)
+      self.assertIsInstance(lock.debuginfo["oldjobinfo"], ValueError)
     self.assertFalse((self.tmpdir/"lock1.lock_2").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
@@ -398,10 +399,12 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     self.assertTrue((self.tmpdir/"lock1.lock_30").exists())
     time.sleep(1)
     clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), dryrun=True, silent=True)
+    subprocess.run(["clean_up_old_job_locks", self.tmpdir, "--hours-old", str(1/3600), "--silent", "--dry-run"], check=True)
     self.assertTrue((self.tmpdir/"lock1.lock_2").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_30").exists())
+    subprocess.run(["clean_up_old_job_locks", self.tmpdir, "--hours-old", str(1/3600), "--silent"], check=True)
     clean_up_old_job_locks(self.tmpdir, howold=datetime.timedelta(seconds=1), silent=True)
     self.assertFalse((self.tmpdir/"lock1.lock_2").exists())
     self.assertFalse((self.tmpdir/"lock1.lock_5").exists())
